==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/sv/lang.php <==
<?php
/**
 * swedish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell[at]mydata.se>
 */
$lang['admin_acl']             = 'Hantera behörighetslistan (ACL)';
$lang['acl_group']             = 'Grupp';
$lang['acl_user']              = 'Användare';
$lang['acl_perms']             = 'Behörighet för';
$lang['page']                  = 'Sida';
$lang['namespace']             = 'Namnrymd';
$lang['p_user_id']             = 'Användaren <b class="acluser">%s</b> har förnärvarande följande rättigheter på sidan <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Användaren <b class="acluser">%s</b> har för närvarande följande rättigheter i namnrymden <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Medlemmar av gruppen <b class="aclgroup">%s</b> har för närvarande följande rättigheter på sidan <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Medlemmar av gruppen <b class="aclgroup">%s</b> har för närvarande följande rättigheter i namnrymden <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Vänligen <b>ange en användare eller grupp</b> i formuläret ovan för att visa eller ändra rättigheterna för sidan <b class="aclpage">%s</b';
$lang['p_choose_ns']           = 'Vänligen <b>ange en användare eller grupp</b> i formuläret ovaan för att visa eller ändra rättigheterna för namnrymden <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Notering: De här rättigheterna är inte explicit satta utan var ärvda från andra grupper eller högre namnrymder.';
$lang['p_isadmin']             = 'Notering: Den valda gruppen eller användaren har alltid fulla rättigheter på grund av att den är konfigurerad som superanvändare.';
$lang['current']               = 'Nuvarande ACL regler';
$lang['where']                 = 'Sida/Namnrymd';
$lang['who']                   = 'Användare/Grupp';
$lang['perm']                  = 'Rättigheter';
$lang['acl_perm0']             = 'Inga';
$lang['acl_perm1']             = 'Läsa';
$lang['acl_perm2']             = 'Redigera';
$lang['acl_perm4']             = 'Skapa';
$lang['acl_perm8']             = 'Ladda upp';
$lang['acl_perm16']            = 'Radera';
$lang['acl_new']               = 'Lägg till ny behörighet';
$lang['acl_mod']               = 'Ändra behörighet';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/sv/lang.php <==
<?php
/**
 * swedish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell[at]mydata.se>
 * @author Dennis Karlsson
 * @author Tormod Otter Johansson <tormod@latast.se>
 * @author emil@sys.nu
 * @author Pontus Bergendahl <pontus.bergendahl@gmail.com>
 */
$lang['admin_acl']             = 'Hantera behörighetslistan (ACL)';
$lang['acl_group']             = 'Grupp';
$lang['acl_user']              = 'Användare';
$lang['acl_perms']             = 'Behörighet för';
$lang['page']                  = 'Sida';
$lang['namespace']             = 'Namnrymd';
$lang['btn_select']            = 'Välj';
$lang['p_user_id']             = 'Användaren <b class="acluser">%s</b> har förnärvarande följande rättigheter på sidan <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Användaren <b class="acluser">%s</b> har för närvarande följande rättigheter i namnrymden <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Medlemmar av gruppen <b class="aclgroup">%s</b> har för närvarande följande rättigheter på sidan <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Medlemmar av gruppen <b class="aclgroup">%s</b> har för närvarande följande rättigheter i namnrymden <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Vänligen <b>ange en användare eller grupp</b> i formuläret ovan för att visa eller ändra rättigheterna för sidan <b class="aclpage">%s</b';
$lang['p_choose_ns']           = 'Vänligen <b>ange en användare eller grupp</b> i formuläret ovaan för att visa eller ändra rättigheterna för namnrymden <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Notering: De här rättigheterna är inte explicit satta utan var ärvda från andra grupper eller högre namnrymder.';
$lang['p_isadmin']             = 'Notering: Den valda gruppen eller användaren har alltid fulla rättigheter på grund av att den är konfigurerad som superanvändare.';
$lang['p_include']             = 'Högre rättigheter inkluderar lägre. Rättigheter för Skapa, Ladda upp och Radera är endast applicerbara namnrymder, inte sidor.';
$lang['current']               = 'Nuvarande ACL regler';
$lang['where']                 = 'Sida/Namnrymd';
$lang['who']                   = 'Användare/Grupp';
$lang['perm']                  = 'Rättigheter';
$lang['acl_perm0']             = 'Inga';
$lang['acl_perm1']             = 'Läsa';
$lang['acl_perm2']             = 'Redigera';
$lang['acl_perm4']             = 'Skapa';
$lang['acl_perm8']             = 'Ladda upp';
$lang['acl_perm16']            = 'Radera';
$lang['acl_new']               = 'Lägg till ny behörighet';
$lang['acl_mod']               = 'Ändra behörighet';
